@@ -1,5 +1,6 @@
 from efsync.utils.dir import create_dir, delete_dir
-from efsync.utils.pip_install import pip_install_requirements
+from efsync.utils.pip_install_local import pip_install_requirements
+from efsync.utils.ec2_install_pip import install_pip_on_ec2
 from efsync.utils.ssh_key import create_ssh_key, delete_ssh_key
 from efsync.utils.ec2_security_group import create_secruity_group, delete_secruity_group, get_security_group_id
 from efsync.utils.ec2_instance import create_ec2_instance, terminate_ec2_instance
