@@ -5,7 +5,9 @@ import os
 
 def write_key_to_file(file_string=None, file_path='.efsync', key_name=''):
     try:
-        with open(f'{file_path}/{key_name}.pem', 'w') as out_file:
+        if os.path.isfile(f'{file_path}/{key_name}.pem'):
+            os.chmod(f'{file_path}/{key_name}.pem' , 0o777)
+        with open(f'{file_path}/{key_name}.pem', 'w+') as out_file:
             out_file.write(file_string)
         os.chmod(f'{file_path}/{key_name}.pem' , 0o400)
     except Exception as e:
